document.addEventListener("DOMContentLoaded", function () {
    const button = document.getElementById("loadFonts");
    const fontList = document.getElementById("fontList");
    const selectedFont = document.getElementById("selectedFont");

    button.addEventListener("click", () => {
        detectFonts().then(fonts => {
            fontList.innerHTML = "";
            fonts.forEach(font => {
                const option = document.createElement("option");
                option.value = font;
                option.textContent = font;
                fontList.appendChild(option);
            });
        });
    });

    fontList.addEventListener("change", () => {
        selectedFont.textContent = `Selected Font: ${fontList.value}`;
    });
});

async function detectFonts() {
    const testString = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
    const baseFonts = ["monospace", "sans-serif", "serif"];
    const fontList = [
        "Arial", "Verdana", "Times New Roman", "Courier New", "Georgia",
        "Palatino Linotype", "Comic Sans MS", "Impact", "Trebuchet MS",
        "Lucida Console", "Garamond", "Century Gothic", "Bookman Old Style",
        "Tahoma", "Calibri", "Cambria", "Futura", "Franklin Gothic Medium",
        "Segoe UI", "Optima", "Baskerville", "Didot", "Rockwell", "Bodoni MT",
        "Consolas", "Lucida Sans", "Copperplate", "Gill Sans", "Geneva"
    ];
    
    const canvas = document.createElement("canvas");
    const context = canvas.getContext("2d");

    function getTextWidth(font) {
        context.font = "72px " + font;
        return context.measureText(testString).width;
    }

    const defaultWidths = {};
    baseFonts.forEach(base => defaultWidths[base] = getTextWidth(base));

    return fontList.filter(font => 
        baseFonts.some(base => getTextWidth(font + "," + base) !== defaultWidths[base])
    );
}
